All Classes and Interfaces

Class
Description
Entry point for assertion methods for shell components.
Represents a provider for commands with their inputs and passwords used in shell interactions.
 
Interface representing a shell screen.
Asserts for ShellScreen.
Client for shell session which can be used as a programmatic way to interact with a shell application.