All Classes and Interfaces

Class
Description
Entry point for assertion methods for shell components.
Interface representing a shell screen.
Asserts for ShellScreen.
Client for shell session which can be used as a programmatic way to interact with a shell application.