Index
All Classes and Interfaces|All Packages
A
- assertThat(ShellScreen) - Static method in class org.springframework.shell.test.ShellAssertions
-
Creates an instance of
ShellScreenAssert.
B
- build() - Method in class org.springframework.shell.test.ShellInputProvider.Builder
C
- command() - Method in record class org.springframework.shell.test.ShellInputProvider
-
Returns the value of the
commandrecord component. - containsText(String) - Method in class org.springframework.shell.test.ShellScreenAssert
-
Verifies that text if found in a screen.
E
- equals(Object) - Method in record class org.springframework.shell.test.ShellInputProvider
-
Indicates whether some other object is "equal to" this one.
- equals(Object) - Method in record class org.springframework.shell.test.ShellScreen
-
Indicates whether some other object is "equal to" this one.
H
- hashCode() - Method in record class org.springframework.shell.test.ShellInputProvider
-
Returns a hash code value for this object.
- hashCode() - Method in record class org.springframework.shell.test.ShellScreen
-
Returns a hash code value for this object.
I
- inputs() - Method in record class org.springframework.shell.test.ShellInputProvider
-
Returns the value of the
inputsrecord component.
L
- lines() - Method in record class org.springframework.shell.test.ShellScreen
-
Returns the value of the
linesrecord component.
O
- org.springframework.shell.test - package org.springframework.shell.test
P
- passwords() - Method in record class org.springframework.shell.test.ShellInputProvider
-
Returns the value of the
passwordsrecord component. - providerFor(String) - Static method in record class org.springframework.shell.test.ShellInputProvider
-
Creates a new input provider for the specified command.
S
- sendCommand(String) - Method in class org.springframework.shell.test.ShellTestClient
-
Execute a command and write its result to the shell screen.
- sendCommand(ShellInputProvider) - Method in class org.springframework.shell.test.ShellTestClient
-
Sends a command to the shell, processes user inputs or passwords as needed, and returns the resulting shell screen output.
- ShellAssertions - Class in org.springframework.shell.test
-
Entry point for assertion methods for shell components.
- ShellAssertions() - Constructor for class org.springframework.shell.test.ShellAssertions
- ShellInputProvider - Record Class in org.springframework.shell.test
-
Represents a provider for commands with their inputs and passwords used in shell interactions.
- ShellInputProvider(String, Deque<String>, Deque<String>) - Constructor for record class org.springframework.shell.test.ShellInputProvider
-
Creates an instance of a
ShellInputProviderrecord class. - ShellInputProvider.Builder - Class in org.springframework.shell.test
- ShellScreen - Record Class in org.springframework.shell.test
-
Interface representing a shell screen.
- ShellScreen(List<String>) - Constructor for record class org.springframework.shell.test.ShellScreen
-
Creates an instance of a
ShellScreenrecord class. - ShellScreenAssert - Class in org.springframework.shell.test
-
Asserts for
ShellScreen. - ShellScreenAssert(ShellScreen) - Constructor for class org.springframework.shell.test.ShellScreenAssert
- ShellTestClient - Class in org.springframework.shell.test
-
Client for shell session which can be used as a programmatic way to interact with a shell application.
- ShellTestClient(CommandParser, CommandRegistry) - Constructor for class org.springframework.shell.test.ShellTestClient
T
- toString() - Method in record class org.springframework.shell.test.ShellInputProvider
-
Returns a string representation of this record class.
- toString() - Method in record class org.springframework.shell.test.ShellScreen
-
Returns a string representation of this record class.
W
- withInput(String...) - Method in class org.springframework.shell.test.ShellInputProvider.Builder
- withPassword(String...) - Method in class org.springframework.shell.test.ShellInputProvider.Builder
All Classes and Interfaces|All Packages