Index

A C E H L O S T 
All Classes and Interfaces|All Packages

A

assertThat(ShellScreen) - Static method in class org.springframework.shell.test.ShellAssertions
Creates an instance of ShellScreenAssert.

C

containsText(String) - Method in class org.springframework.shell.test.ShellScreenAssert
Verifies that text if found in a screen.

E

equals(Object) - Method in record class org.springframework.shell.test.ShellScreen
Indicates whether some other object is "equal to" this one.

H

hashCode() - Method in record class org.springframework.shell.test.ShellScreen
Returns a hash code value for this object.

L

lines() - Method in record class org.springframework.shell.test.ShellScreen
Returns the value of the lines record component.

O

org.springframework.shell.test - package org.springframework.shell.test
 

S

sendCommand(String) - Method in class org.springframework.shell.test.ShellTestClient
Execute a command and write its result to the shell screen.
ShellAssertions - Class in org.springframework.shell.test
Entry point for assertion methods for shell components.
ShellAssertions() - Constructor for class org.springframework.shell.test.ShellAssertions
 
ShellScreen - Record Class in org.springframework.shell.test
Interface representing a shell screen.
ShellScreen(List<String>) - Constructor for record class org.springframework.shell.test.ShellScreen
Creates an instance of a ShellScreen record class.
ShellScreenAssert - Class in org.springframework.shell.test
Asserts for ShellScreen.
ShellScreenAssert(ShellScreen) - Constructor for class org.springframework.shell.test.ShellScreenAssert
 
ShellTestClient - Class in org.springframework.shell.test
Client for shell session which can be used as a programmatic way to interact with a shell application.
ShellTestClient(CommandParser, CommandRegistry) - Constructor for class org.springframework.shell.test.ShellTestClient
Create a ShellTestClient using the given CommandParser and CommandRegistry.

T

toString() - Method in record class org.springframework.shell.test.ShellScreen
Returns a string representation of this record class.
A C E H L O S T 
All Classes and Interfaces|All Packages